@@ -1,6 +1,6 @@
 ##----------------------------------------------------------------------------
 ## PO Files Manipulation - ~/lib/Text/PO.pm
-## Version v0.2.0
+## Version v0.2.1
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2018/06/21
@@ -33,7 +33,7 @@ BEGIN
         my $tz = DateTime::TimeZone->new( name => 'local' );
     };
     use constant HAS_LOCAL_TZ => ( $@ ? 0 : 1 );
-    our $VERSION = 'v0.2.0';
+    our $VERSION = 'v0.2.1';
 };
 
 use strict;
@@ -248,7 +248,7 @@ sub content_type { return( shift->_set_get_meta_value( 'Content-Type' ) ); }
 sub current_lang
 {
     my $self = shift( @_ );
-    return( $ENV{LANGUAGE} || $ENV{LANG} );
+    return( ( $ENV{LANGUAGE} || $ENV{LANG} ) ? [split( /:/, ( $ENV{LANGUAGE} || $ENV{LANG} ) )]->[0] : '' );
 }
 
 sub decode
@@ -1333,7 +1333,7 @@ Text::PO - Read and write PO files
 
 =head1 VERSION
 
-    v0.2.0
+    v0.2.1
 
 =head1 DESCRIPTION
 
